close all
clear all

% set this to either 0.5 or 0.25 to generate either table
ds_fact = 0.5;
%ds_fact = 0.25;

% directories
ipDir = ['table/' num2str(ds_fact) '/'];
ipGt = [ipDir 'gt/'];
ipClean = [ipDir 'clean/'];
ipScsr = [ipDir 'scsr/'];
ipMRF = [ipDir 'mrf/'];
ipNips = [ipDir 'nips/'];
ipYang = [ipDir 'yang/'];
ipUs = [ipDir 'us/'];  % our results ECCV 2012

% files
filesGT = dir([ipGt '*gt.png']);
filesClean = dir([ipClean '*clean.png']);
filesScsr = dir([ipScsr '*.mat']);
filesMRF = dir([ipMRF '*.png']);
filesYang = dir([ipYang '*.png']);
filesNIPS = dir([ipNips '*.pgm']);
filesUs = dir([ipUs '*.mat']);

errType = 'rmse'; %perc1, rmse
nMethods = 6;
nScenes = 4;

results = ones(nMethods, nScenes)*Inf;

% loop through the 4 different scenes
for i=1:4;
    
    % middlebury disparites are scaled
    if i==1
        scaleFact = 4;
        border = 10;
    elseif i==2
        scaleFact = 4;
        border = 10;
    elseif i==3
        scaleFact = 16;
        border = 18;
    elseif i==4
        scaleFact = 8;
        border = 10;
    end
    
    
    gtIm = double(imread([ipGt filesGT(i).name]))/scaleFact;
    gtIm(1:border,:) = 0;
    gtIm(:,1:border) = 0;
    gtIm(:,end-border+1:end) = 0;
    gtIm(end-border+1:end,:) = 0;
    
    
    load([ipScsr filesScsr(i).name]);
    gtScsr = D/scaleFact;
    if (size(gtScsr,1) > size(gtIm,1))
        gtScsr = imresize(gtScsr,size(gtIm), 'nearest');
    end    
    
    
    gtMRF = double(imread([ipMRF filesMRF(i).name]))/scaleFact;
    gtMRF = gtMRF(:,:,1);
    if (size(gtMRF,1) > size(gtIm,1))
        gtMRF = imresize(gtMRF,size(gtIm), 'nearest');
    end
    
    
    gtNips = double(imread([ipNips filesNIPS(i).name]))/scaleFact;
    gtYang = double(imread([ipYang filesYang(i).name]))/scaleFact;
    
    
    %% analyitic - computed without holes
    gtImClean = double(imread([ipClean filesClean(i).name]))/scaleFact;
    gtImNN = imresize(imresize(gtImClean,ds_fact,'nearest'),[size(gtImClean)],'nearest');
    gtImBI = imresize(imresize(gtImClean,ds_fact,'nearest'),[size(gtImClean)],'bilinear');
    gtImBC = imresize(imresize(gtImClean,ds_fact,'nearest'),[size(gtImClean)]);
    
    
    %% our results
    load([ipUs filesUs(i).name]);
    gtUs = superRes;
    gtUs = depthToDisp(gtUs, gtImClean, scaleFact);

    if (size(gtUs,1) > size(gtIm,1))
        gtUs = imresize(gtUs,size(gtIm), 'nearest');
    end
    
    
    results(1,i) = calcError(gtNips, gtIm, errType);
    results(2,i) = calcError(gtYang, gtIm, errType);    
    results(3,i) = calcError(gtImNN, gtIm, errType);
    results(4,i) = calcError(gtScsr, gtIm, errType);
    results(5,i) = calcError(gtMRF, gtIm, errType);
    results(6,i) = calcError(gtUs, gtIm, errType);
    
end


%% Write latex table 
% Yang does not use the middlebury GT for teddy and cones, I cannot
% recreate his scores exactly, but he gave me his ip
fprintf('\n \n');
fprintf('Cones & Teddy & Tsukuba & Venus\n');
[v ind] = min(results);
indM = zeros(size(results));
sub = sub2ind(size(results), ind ,[1:nScenes]);
indM(sub) = 1;
for j=1:nMethods
    for i = 1:nScenes
        if (indM(j,i) == 1)
            fprintf('&\\textbf{%1.3f} ', results(j,i));
        else
            fprintf('&%6.3f ', results(j,i));
        end
    end
    fprintf(' \\\\ \n');
end







